@@ -1,4 +1,4 @@
-package Net::MAC::Vendor; # git description: v1.263-8-g8a60efe
+package Net::MAC::Vendor; # git description: v1.265-4-gc604faa
 # ABSTRACT: Look up the vendor for a MAC
 
 use strict;
@@ -75,7 +75,7 @@ use Carp ();
 use Mojo::URL;
 use Mojo::UserAgent;
 
-our $VERSION = '1.264';
+our $VERSION = '1.266';
 
 #pod =item run( @macs )
 #pod
@@ -473,7 +473,7 @@ sub load_cache {
 				return;
 				}
 
-			do { local( @ARGV, $/ ) = $source; <> }
+			do { local( *ARGV, $/ ); @ARGV = $source; <> }
 			}
 		else {
 			#say time . " Fetching URL";
@@ -519,7 +519,7 @@ sub load_cache {
 
 sub _bunzip {
 	my $content = shift;
-	if (eval { require Compress::Bzip2; 1 }) {
+	if (eval { +require Compress::Bzip2; 1 }) {
 		return Compress::Bzip2::memBunzip($content);
 		}
 	else {
@@ -538,7 +538,7 @@ sub _bunzip {
 
 sub _gunzip {
 	my $content = shift;
-	if (eval { require Compress::Zlib; 1 }) {
+	if (eval { +require Compress::Zlib; 1 }) {
 		return Compress::Zlib::memGunzip($content);
 		}
 	else {
@@ -617,7 +617,7 @@ Net::MAC::Vendor - Look up the vendor for a MAC
 
 =head1 VERSION
 
-version 1.264
+version 1.266
 
 =head1 SYNOPSIS
 
@@ -871,7 +871,7 @@ L<Net::MacMap>
 Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Net-MAC-Vendor>
 (or L<bug-Net-MAC-Vendor@rt.cpan.org|mailto:bug-Net-MAC-Vendor@rt.cpan.org>).
 
-I am also usually active on irc, as 'ether' at C<irc.perl.org>.
+I am also usually active on irc, as 'ether' at C<irc.perl.org> and C<irc.libera.chat>.
 
 =head1 AUTHOR
 
@@ -879,7 +879,7 @@ brian d foy <bdfoy@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords brian d foy Karen Etheridge Frank Maas openstrike Dean Hamstead
+=for stopwords brian d foy Karen Etheridge Frank Maas openstrike Christopher Layne Dean Hamstead
 
 =over 4
 
@@ -901,6 +901,10 @@ openstrike <git@openstrike.co.uk>
 
 =item *
 
+Christopher Layne <clayne@anodized.com>
+
+=item *
+
 Dean Hamstead <dean@fragfest.com.au>
 
 =back
